
Imports System
Imports System.Drawing
Imports System.ComponentModel
Imports System.Runtime.Serialization
Imports System.Diagnostics
Imports Syncfusion.Windows.Forms.Diagram


'/ <summary>
'/ Custom Tool that draws a Rectangle with an bitmap node in it.
'/ </summary>

Public Class CustomRectangleTool
    Inherits RectangleTool
    '/ <summary>
    '/ Factory method used to create shape objects drawn by this tool.
    '/ </summary>
    Private shapeFactory1 As shapeFactory

    Protected displaybmp As Bitmap
    Protected bDisplayImageAsNode As Boolean = False
    
    
    Public Property DisplayImage() As Bitmap
        Get
            Return Me.displaybmp
        End Get
        Set
            Me.displaybmp = value
        End Set
    End Property 
    
    Public Property DisplayImageAsNode() As Boolean
        Get
            Return Me.bDisplayImageAsNode
        End Get
        Set
            Me.bDisplayImageAsNode = value
        End Set
    End Property
     
    Public Sub New()
        MyBase.New("CustomRectangleTool")
        Me.shapeFactory1 = New ShapeFactory(AddressOf DefaultFactory)
    End Sub 'New


    Public Sub New(ByVal name As String)
        MyBase.New(name)
        Me.shapeFactory1 = New ShapeFactory(AddressOf DefaultFactory)
    End Sub 'New


    ' Create the Rectangle shape and insert the node using the InsertNodesCmd command. 
    ' Depending on the 'bDisplayImageAsNode' flag the image is displayed inside the Shape 
    ' as a fill texture or as a separate Bitmap node.
    Protected Overrides Sub OnRectangleComplete()
        Dim worldPts() As PointF = {New PointF(Me.rect.Left, Me.rect.Top), New PointF(Me.rect.Right, Me.rect.Bottom)}

        If Not (Me.shapeFactory1 Is Nothing) Then
            Dim shape As Shape = Me.shapeFactory1(worldPts)

            If Not (shape Is Nothing) Then
                Dim cmd As New InsertNodesCmd()
                cmd.Nodes.Add(shape)
                If Not (Me.displaybmp Is Nothing) Then

                    If Me.bDisplayImageAsNode = True Then
                        Dim bmpnode As New BitmapNode(Me.displaybmp, RectangleF.Inflate(Me.rect, -5, -5))
                        cmd.Nodes.Add(bmpnode)
                    Else
                        ' Fill the Shape interior with the DisplayImage
                        shape.SetPropertyValue("FillType", FillStyle.FillType.Texture)
                        shape.SetPropertyValue("FillTexture", Me.displaybmp)
                        shape.SetPropertyValue("FillTextureWrapMode", System.Drawing.Drawing2D.WrapMode.Clamp)
                    End If
                End If
                Try
                    Me.Controller.ExecuteCommand(cmd)
                Catch ex As Exception
                    Me.Controller.DeactivateTool(Me)
                    Me.View.Refresh()
                    Throw ex
                End Try
            End If
        End If

        Me.Controller.DeactivateTool(Me)
    End Sub 'OnRectangleComplete
End Class 'CustomRectangleTool